"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var QueryString = require("querystring");
/**
 * 浏览器端的httpClient，支持proxy
 */
var BrowserHttpClient = /** @class */ (function () {
    function BrowserHttpClient() {
    }
    BrowserHttpClient.put = function (url, formData) {
        if (formData === void 0) { formData = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var xhr = new XMLHttpRequest();
                        xhr.addEventListener("loadend", function (event) {
                            if (xhr.status === 200) {
                                resolve(xhr);
                            }
                            else {
                                reject(event);
                            }
                        });
                        xhr.addEventListener("error", function (event) {
                            reject(event);
                        });
                        xhr.addEventListener("progress", function () {
                        });
                        xhr.addEventListener("abort", function (event) {
                            reject(event);
                        });
                        xhr.open("PUT", url);
                        xhr.setRequestHeader("Content-type", "application/json");
                        xhr.send(JSON.stringify(formData));
                    })];
            });
        });
    };
    BrowserHttpClient["delete"] = function (url, formData) {
        if (formData === void 0) { formData = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var xhr = new XMLHttpRequest();
                        xhr.addEventListener("loadend", function (event) {
                            if (xhr.status === 200) {
                                resolve(xhr);
                            }
                            else {
                                reject(event);
                            }
                        });
                        xhr.addEventListener("error", function (event) {
                            reject(event);
                        });
                        xhr.addEventListener("progress", function () {
                        });
                        xhr.addEventListener("abort", function (event) {
                            reject(event);
                        });
                        xhr.open("DELETE", url);
                        xhr.setRequestHeader("Content-type", "application/json");
                        xhr.send(JSON.stringify(formData));
                    })];
            });
        });
    };
    /**
     * Post用这种方法，主要是提交json数据。但是对于非json数据的文件上传，还需要编写upload方法，以便支持流式上传
     * @param url
     * @param formData
     */
    BrowserHttpClient.post = function (url, formData) {
        if (formData === void 0) { formData = {}; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var xhr = new XMLHttpRequest();
                        xhr.addEventListener("loadend", function (event) {
                            if (xhr.status === 200) {
                                try {
                                    var data = JSON.parse(xhr.responseText);
                                    resolve(data);
                                }
                                catch (error) {
                                    console.log({ xhr: xhr, error: error });
                                    reject({ error: new Error("JSON_PARSE_ERROR"), xhr: xhr });
                                }
                            }
                            else {
                                reject(event);
                            }
                        });
                        xhr.addEventListener("error", function (event) {
                            reject(event);
                        });
                        xhr.addEventListener("progress", function () {
                        });
                        xhr.addEventListener("abort", function (event) {
                            reject(event);
                        });
                        try {
                            xhr.open("POST", url);
                            xhr.setRequestHeader("Content-type", "application/json");
                            xhr.send(JSON.stringify(formData));
                        }
                        catch (error) {
                            reject(error);
                        }
                    })];
            });
        });
    };
    BrowserHttpClient.getByURI = function (uri, query) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, BrowserHttpClient.get(uri + "?" + QueryString.stringify(query))];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    BrowserHttpClient.get = function (url, options) {
        if (options === void 0) { options = { proxyOptions: {} }; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var xhr, data;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (options.proxy) {
                            url = BrowserHttpClient.getProxyURL(url, options);
                        }
                        if (typeof options.proxyOptions !== "object") {
                            options.proxyOptions = {};
                        }
                        if (options.proxyOptions.file === true) {
                            return [2 /*return*/, { url: url }];
                        }
                        return [4 /*yield*/, BrowserHttpClient.getXMLHttpRequest(url)];
                    case 1:
                        xhr = _a.sent();
                        try {
                            if (options.text === true) {
                                return [2 /*return*/, xhr.responseText];
                            }
                            data = JSON.parse(xhr.responseText);
                            if (options.proxyOptions.text) {
                                return [2 /*return*/, data.text];
                            }
                            return [2 /*return*/, data];
                        }
                        catch (error) {
                            console.log({ xhr: xhr, error: error });
                            throw new Error("JSON_PARSE_ERROR");
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * 将url获取前面path和host部分
     */
    BrowserHttpClient.getURL = function () {
    };
    /**
     * 将url解析成querystring
     */
    BrowserHttpClient.getQuery = function (url) {
    };
    /**
     * 将cookies解析成cookies
     */
    BrowserHttpClient.getCookiesByString = function (cookie) {
    };
    BrowserHttpClient.getXMLHttpRequest = function (url) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var xhr = new XMLHttpRequest();
                        xhr.addEventListener("loadend", function (event) {
                            if (xhr.status === 200) {
                                resolve(xhr);
                            }
                            else {
                                reject(event);
                            }
                        });
                        xhr.addEventListener("error", function (event) {
                            reject(event);
                        });
                        xhr.addEventListener("progress", function () {
                        });
                        xhr.addEventListener("abort", function (event) {
                            reject(event);
                        });
                        xhr.open("GET", url);
                        xhr.send();
                    })];
            });
        });
    };
    BrowserHttpClient.getProxyURL = function (url, options) {
        if (options === void 0) { options = {}; }
        if (options.proxyOptions.file) {
            return "//" + window.location.host +
                "/kemao-lark/net/HttpClient/get/?" +
                QueryString.stringify({
                    url: url,
                    options: JSON.stringify(options)
                });
        }
        return "/kemao-lark/net/HttpClient/get.json?" +
            QueryString.stringify({
                url: url,
                options: JSON.stringify(options)
            });
    };
    return BrowserHttpClient;
}());
exports.BrowserHttpClient = BrowserHttpClient;
//# sourceMappingURL=BrowserHttpClient.js.map