"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var LarkDateDto_1 = require("../../Server/Utils/LarkDate/LarkDateDto");
var BrowserLarkError_1 = require("../Log/BrowserLarkError");
var BrowserLarkMath_1 = require("./BrowserLarkMath");
var BrowserLarkDate = /** @class */ (function () {
    function BrowserLarkDate() {
    }
    /**
     * 获得星期
     * @param date 时间
     */
    BrowserLarkDate.getWeekStringByDate = function (date) {
        var week = date.getDay();
        return this.getWeekString(week);
    };
    BrowserLarkDate.getWeekString = function (week) {
        switch (week) {
            case LarkDateDto_1.WEEK.SUNDAY:
                return "星期天";
            case LarkDateDto_1.WEEK.MONDAY:
                return "星期一";
            case LarkDateDto_1.WEEK.TUESDAY:
                return "星期二";
            case LarkDateDto_1.WEEK.WEDNESDAY:
                return "星期三";
            case LarkDateDto_1.WEEK.THURSDAY:
                return "星期四";
            case LarkDateDto_1.WEEK.FRIDAY:
                return "星期五";
            case LarkDateDto_1.WEEK.SATURDAY:
                return "星期六";
            default:
                throw new BrowserLarkError_1.BrowserLarkError("错误的周期枚举", { week: week });
        }
    };
    /**
     * 实例化一个时间对象，传什么得什么
     * @param date 时间
     */
    BrowserLarkDate.getDate = function (date) {
        var defaultDate = {
            year: 0,
            month: 0,
            day: 0,
            hour: 0,
            minutes: 0,
            seconds: 0,
            milliseconds: 0
        };
        var dateData = Object.assign(defaultDate, date);
        if (dateData.month > 0) {
            dateData.month = dateData.month - 1;
        }
        // if (dateData.month === 0) {
        //     dateData.month = 1
        // }
        if (dateData.day === 0) {
            dateData.day = 1;
        }
        return new Date(dateData.year, dateData.month, dateData.day, dateData.hour, dateData.minutes, dateData.seconds, dateData.milliseconds);
    };
    /**
     * 时间格式化
     * @param Date date
     * @param format "yyyy-MM-dd hh:mm:ss.uuu"
     * @return string date
     */
    BrowserLarkDate.format = function (date, format) {
        if (format === void 0) { format = "yyyy-MM-dd hh:mm:ss.uuu"; }
        var o = {
            "M+": date.getMonth() + 1,
            "d+": date.getDate(),
            "h+": date.getHours(),
            "m+": date.getMinutes(),
            "q+": Math.floor((date.getMonth() + 3) / 3),
            "s+": date.getSeconds(),
            "u+": date.getMilliseconds()
        };
        if (/(y+)/.test(format)) {
            format = format.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
        }
        for (var k in o) {
            if (o.hasOwnProperty(k)) {
                var pad = "00";
                if (k === "u+") {
                    pad = "000";
                }
                if (new RegExp("(" + k + ")").test(format)) {
                    format = format
                        .replace(RegExp.$1, RegExp.$1.length === 1 ? o[k] : (pad + o[k]).substr(("" + o[k]).length));
                }
            }
        }
        return format;
    };
    /**
     * @param Date date
     * @return string  "yyyy-MM-dd hh:mm:ss.uuu"
     * @deprecated 过时了，直接使用format
     */
    BrowserLarkDate.getDateTimeString = function (date) {
        return this.format(date, "yyyy-MM-dd hh:mm:ss.uuu");
    };
    /**
     * 获得字符串的时间，不带任何符号。数字类型
     * @param Date date
     * @return number "yyyyMMddhhmmssuuu"
     */
    BrowserLarkDate.getDateTimeStringNumber = function (date) {
        return Number(this.format(date, "yyyyMMddhhmmssuuu"));
    };
    BrowserLarkDate.getDateString = function (date) {
        return this.format(date, "yyyyMMdd");
    };
    BrowserLarkDate.getDateStringNumber = function (date) {
        return Number(this.format(date, "yyyyMMdd"));
    };
    /**
     * 代码延迟执行
     * @param timeout 延时时间
     */
    BrowserLarkDate.delay = function (timeout) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve) {
                        console.log("delayTimeout", timeout);
                        setTimeout(function () {
                            resolve();
                        }, timeout);
                    })];
            });
        });
    };
    /**
     * 代码延迟区间执行
     * @param min 最小值
     * @param max 最大值
     */
    BrowserLarkDate.delayRange = function (min, max, callback) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var timeout;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        timeout = BrowserLarkMath_1.BrowserLarkMath.random(min, max);
                        if (!callback) return [3 /*break*/, 2];
                        return [4 /*yield*/, callback(timeout)];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2: return [4 /*yield*/, this.delay(timeout)];
                    case 3:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    BrowserLarkDate.tideInterval = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.delayRange(260, 333)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    return BrowserLarkDate;
}());
exports.BrowserLarkDate = BrowserLarkDate;
//# sourceMappingURL=BrowserLarkDate.js.map