"use strict";
exports.__esModule = true;
var fs = require("fs-extra");
var LarkLogger_1 = require("../Log/Logger/LarkLogger");
var LarkError_1 = require("../Log/LarkError");
var logger = new LarkLogger_1.LarkLogger("Core/Application");
var Application = /** @class */ (function () {
    function Application() {
    }
    /**
     * 多次调用，不防异步
     */
    Application.ready = function () {
        if (this.init === false) {
            if (process.env.debug) {
                this.debug = true;
            }
            else {
                this.debug = false;
            }
            var packageInfo = fs.readJSONSync("./package.json");
            this.appName = packageInfo.name;
            this.appVersion = packageInfo.version;
            this.host = packageInfo.host;
            this.port = packageInfo.port;
            this.version = packageInfo.version;
            // logger.log(
            //     "Application.init",
            //     JSON.stringify({
            //         appName: this.appName,
            //         appVersion: this.appVersion,
            //         debug: this.debug,
            //         host: this.host,
            //         port: this.port
            //     }),
            // )
            this.init = true;
        }
        return this;
    };
    Application.getVersion = function () {
        this.ready();
        return this.version;
    };
    Application.getPackageName = function () {
        this.ready();
        return this.appName;
    };
    /**
     * 获取完整的带版本号的包名
     * @example kemao-lark@6.0.0
     */
    Application.getFullPackageName = function () {
        this.ready();
        return this.appName + "@" + this.version;
    };
    Application.getLarkServer = function () {
        this.ready();
        var server = "https://lark.kemao.com";
        if (this.isDebug()) {
            server = server.replace(".kemao.", ".kemao-dev.");
        }
        return server;
    };
    Application.getRemoteServer = function () {
        this.ready();
        if (this.host === null || typeof this.host === "undefined") {
            throw new Error("没有配置host，请配置host。或使用getLocalServer");
        }
        var host = this.host;
        if (this.isDebug()) {
            host = host.replace(".kemao.", ".kemao-dev.");
        }
        return "https://" + host;
    };
    Application.getLocalServer = function () {
        this.ready();
        if (this.port === null) {
            throw new LarkError_1.LarkError("Application初始化失败或未设置无法读取port");
        }
        return "https://127.0.0.1:" + this.port;
    };
    Application.setDebug = function (debug) {
        this.ready();
        this.debug = debug;
    };
    Application.isDebug = function () {
        this.ready();
        return this.debug;
    };
    Application.init = false;
    Application.appName = null;
    Application.appVersion = null;
    Application.debug = false;
    Application.port = null;
    Application.host = null;
    Application.version = null;
    return Application;
}());
exports.Application = Application;
//# sourceMappingURL=Application.js.map