/**
 * 消费者模型，消费者通过监听消息，来获取任务。
 * 一个项目可以产生非常多的消费者，他们都能通过统一的接口，来获取消息。然后根据消息的内容，决定怎么处理。
 * 当它处理完这个消息之后，会更新这个消息的状态为Resolve或Reject，即成功或失败
 * 所有的消息本身当被生产者创建之后其状态为Ready,一旦分发出去之后，其状态变成Pending
 * 如果一个任务超过10分钟仍然未被消费者“消费”完，则有可能被另一个消费者领取，由另一个消费者接受并处理它
 * 对于消费者来说，如果它获取到了任务不属于它，或它无法处理，那么它会将这个任务还回去。
 * （是否会造成性能问题？无效的请求，但对于消费者来说，消费者的类型太多，定点投放会加大中央服务器的压力）
 * 消息的投放是个高效的过程，不涉及过多的运算，故瞬间的并发问题不大。
 * 每个消费者每隔10秒种询问一次有没有消息
 * 进行主动的消息订阅，而不是盲发
 */
export declare class Consumers {
    private static id;
    private static eventList;
    private static status;
    private static total;
    /**
     * 绑定监听事件
     * 正常执行完视为任务成功，将会通知该消息完成
     * 出现异常，更新该消息为异常，异常的消息将会被其它消费者去消费？或者堆积？
     */
    static addEventListener(topic: string, handler: (message: any) => void | Promise<void>): void;
    /**
     * 开始监听
     * 每10秒检测一次
     * 根据事件，获取数据，直到某个消息完全完成，再切换下一个消息
     */
    static listen(always?: boolean | number): Promise<void>;
    static off(): Promise<void>;
    static close(): Promise<void>;
    static getID(): any;
    private static bindEvent();
    private static updateNSQStatus(id, status);
    private static getNSQRecord(topic);
}
