"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var NSQDto_1 = require("./NSQDto");
var UUID = require("uuid");
var LarkDate_1 = require("../Utils/LarkDate");
var LarkFatalError_1 = require("../Log/LarkFatalError");
var NSQ_1 = require("./NSQ");
var LarkLogger_1 = require("../Log/Logger/LarkLogger");
var logger = new LarkLogger_1.LarkLogger("NSQ/Consumers");
/**
 * 消费者模型，消费者通过监听消息，来获取任务。
 * 一个项目可以产生非常多的消费者，他们都能通过统一的接口，来获取消息。然后根据消息的内容，决定怎么处理。
 * 当它处理完这个消息之后，会更新这个消息的状态为Resolve或Reject，即成功或失败
 * 所有的消息本身当被生产者创建之后其状态为Ready,一旦分发出去之后，其状态变成Pending
 * 如果一个任务超过10分钟仍然未被消费者“消费”完，则有可能被另一个消费者领取，由另一个消费者接受并处理它
 * 对于消费者来说，如果它获取到了任务不属于它，或它无法处理，那么它会将这个任务还回去。
 * （是否会造成性能问题？无效的请求，但对于消费者来说，消费者的类型太多，定点投放会加大中央服务器的压力）
 * 消息的投放是个高效的过程，不涉及过多的运算，故瞬间的并发问题不大。
 * 每个消费者每隔10秒种询问一次有没有消息
 * 进行主动的消息订阅，而不是盲发
 */
var Consumers = /** @class */ (function () {
    function Consumers() {
    }
    /**
     * 绑定监听事件
     * 正常执行完视为任务成功，将会通知该消息完成
     * 出现异常，更新该消息为异常，异常的消息将会被其它消费者去消费？或者堆积？
     */
    Consumers.addEventListener = function (topic, handler) {
        logger.info("✔️", "addEventListener", topic);
        this.eventList[topic] = handler;
    };
    /**
     * 开始监听
     * 每10秒检测一次
     * 根据事件，获取数据，直到某个消息完全完成，再切换下一个消息
     */
    Consumers.listen = function (always) {
        if (always === void 0) { always = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _a, _b, _i, topic, nsqRecord, error_1;
            return tslib_1.__generator(this, function (_c) {
                switch (_c.label) {
                    case 0:
                        this.bindEvent();
                        this.status = true;
                        _c.label = 1;
                    case 1:
                        if (!this.status) return [3 /*break*/, 18];
                        if (this.status === false) {
                            return [3 /*break*/, 18];
                        }
                        _a = [];
                        for (_b in this.eventList)
                            _a.push(_b);
                        _i = 0;
                        _c.label = 2;
                    case 2:
                        if (!(_i < _a.length)) return [3 /*break*/, 14];
                        topic = _a[_i];
                        _c.label = 3;
                    case 3:
                        if (!true) return [3 /*break*/, 13];
                        return [4 /*yield*/, this.getNSQRecord(topic)]; // 从协调者那里获取一个消息
                    case 4:
                        nsqRecord = _c.sent() // 从协调者那里获取一个消息
                        ;
                        if (!(nsqRecord !== null)) return [3 /*break*/, 11];
                        logger.log("获得了消息", nsqRecord);
                        logger.log("命中消息", "topic:", nsqRecord.topic);
                        _c.label = 5;
                    case 5:
                        _c.trys.push([5, 8, , 10]);
                        return [4 /*yield*/, this.eventList[nsqRecord.topic](nsqRecord.message)
                            // 处理成功了，更新消息的状态
                        ];
                    case 6:
                        _c.sent();
                        // 处理成功了，更新消息的状态
                        logger.warn("更新消息状态", "topic:", nsqRecord.topic, NSQDto_1.NSQ_STATUS.RESOLVE);
                        return [4 /*yield*/, this.updateNSQStatus(nsqRecord.id, NSQDto_1.NSQ_STATUS.RESOLVE)];
                    case 7:
                        _c.sent();
                        return [3 /*break*/, 10];
                    case 8:
                        error_1 = _c.sent();
                        // 处理失败了，更新消息的状态
                        logger.error("更新消息状态", "topic:", nsqRecord.topic, NSQDto_1.NSQ_STATUS.REJECT, error_1);
                        return [4 /*yield*/, this.updateNSQStatus(nsqRecord.id, NSQDto_1.NSQ_STATUS.REJECT)];
                    case 9:
                        _c.sent();
                        return [3 /*break*/, 10];
                    case 10: return [3 /*break*/, 12];
                    case 11: return [3 /*break*/, 13];
                    case 12: return [3 /*break*/, 3];
                    case 13:
                        _i++;
                        return [3 /*break*/, 2];
                    case 14:
                        if (!(always === false || typeof always === "number" && always > this.total)) return [3 /*break*/, 15];
                        this.off();
                        return [3 /*break*/, 18];
                    case 15:
                        logger.log("没有消息，暂停");
                        return [4 /*yield*/, LarkDate_1.LarkDate.delay(10 * 1000)];
                    case 16:
                        _c.sent();
                        this.total++;
                        _c.label = 17;
                    case 17: return [3 /*break*/, 1];
                    case 18: return [2 /*return*/];
                }
            });
        });
    };
    Consumers.off = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                logger.log("Consumers", "等待下轮退出...");
                this.status = false;
                return [2 /*return*/];
            });
        });
    };
    Consumers.close = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                logger.log("Consumers.close", "等待下轮退出...");
                this.status = false;
                return [2 /*return*/];
            });
        });
    };
    Consumers.getID = function () {
        return this.id;
    };
    Consumers.bindEvent = function () {
        var _this = this;
        process.once("SIGINT", function () {
            _this.off();
        });
    };
    Consumers.updateNSQStatus = function (id, status) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, NSQ_1.NSQ.updateStatus(id, status)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    Consumers.getNSQRecord = function (topic) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var nsqRecord, error_2;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        return [4 /*yield*/, NSQ_1.NSQ.getNSQ(topic)];
                    case 1:
                        nsqRecord = _a.sent();
                        logger.log("getNSQRecord", typeof nsqRecord, nsqRecord);
                        return [2 /*return*/, nsqRecord.record];
                    case 2:
                        error_2 = _a.sent();
                        throw new LarkFatalError_1.LarkFatalError("无法获取NSQRecord", { error: error_2 });
                    case 3: return [2 /*return*/];
                }
            });
        });
    };
    Consumers.id = UUID();
    Consumers.eventList = {};
    Consumers.status = null;
    Consumers.total = 0;
    return Consumers;
}());
exports.Consumers = Consumers;
//# sourceMappingURL=Consumers.js.map