/**
 * 消息的状态
 */
export declare enum NSQ_STATUS {
    /**
     * 准备中
     */
    READY = -1,
    /**
     * 正在执行中
     */
    PENDING = 0,
    /**
     * 已完成
     */
    RESOLVE = 1,
    /**
     * 失败了
     */
    REJECT = 2,
}
/**
 * DBName: LarkDB
 * Collection: NSQTopic
 */
export interface NSQRecord {
    id?: number;
    /**
     * topic,建议使用格式 协议://域名/path?query#hash 命名
     * @example https://lark.kemao.com/Utils/LarkSequence/NPMSequence.json?packageName=kemao-lark
     * @example https://maple-world.kemao.com/Server/BingWallpaper/BingWallpaper.ts#capture
     * @example https://maple-world.kemao.com/Server/Book/CBIP/CBIPList.ts#getList
     */
    topic: string;
    /**
     * 消息的主体内容，不建议放太多数据
     * @example null
     * @example [1,2,3]
     * @example "message"
     * @example {id: 1}
     */
    message?: any;
    /**
     * 任务的状态
     */
    status: NSQ_STATUS;
    /**
     * 版本号，
     * 例如
     * 1.0.1，每个topic的版本号，默认为其包的版本号。不可更改
     * 引入版本号规则是为了避免不同的消息的代码变更后，导致消息无法正确处理问题
     * 一般引用两个消息节点机器，启动新的节点机器后，旧的节点将逐步废弃
     * 如何解决旧的节点也在产生新的消息问题？
     *  如果入口已经被掐了，那么旧的节点的消息应该会逐步的慢慢消亡和被取代才对。
     * 通过docker，新旧两线并行运行
     */
    version?: string;
    /**
     * 消息的优先级别。级别越高，越容易被消费者接收并进行处理。通常可用于每日消息的插队。默认值为0，可以为负数
     */
    weight?: number;
    /**
     * 创建时间
     */
    createDatetime?: Date;
    /**
     * 更新时间
     */
    updateDatetime?: Date;
}
