"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var Request = require("request");
var zlib = require("zlib");
var LarkError_1 = require("../Log/LarkError");
var HttpClientDto_1 = require("./HttpClient/HttpClientDto");
var index_1 = require("../index");
var LarkLogger_1 = require("../Log/Logger/LarkLogger");
var logger = new LarkLogger_1.LarkLogger("Net/HttpClient");
/**
 * node端的网络模块，可以用来下载网页或下载json数据等
 * 为断点的方式下载，但是不支持续传。后面可以增加续传功能结合redis
 */
var HttpClient = /** @class */ (function () {
    function HttpClient() {
    }
    /**
     * 获取网络的json数据
     * @param url
     */
    HttpClient.getJSON = function (url) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var buffer, text, json, err;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.get(url)];
                    case 1:
                        buffer = _a.sent();
                        text = buffer.toString();
                        // logger.log("HttpClient.getJSON", { text })
                        try {
                            json = JSON.parse(text);
                            return [2 /*return*/, json];
                        }
                        catch (error) {
                            err = new Error();
                            err.name = HttpClientDto_1.ERROR_HttpClient[HttpClientDto_1.ERROR_HttpClient.ERROR_JSON_PARSE_FAIL];
                            throw err;
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    HttpClient.postLocalServer = function (path, formData) {
        if (formData === void 0) { formData = null; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, HttpClient.post(index_1.Application.getLocalServer() +
                            path, formData, "json")];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    HttpClient.postRemoteLarkServer = function (path, formData) {
        if (formData === void 0) { formData = null; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, HttpClient.post(index_1.Application.getRemoteServer() +
                            path, formData, "json")];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    /**
     * post数据
     */
    HttpClient.post = function (url, formData, format) {
        if (formData === void 0) { formData = null; }
        if (format === void 0) { format = "text"; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                        return tslib_1.__generator(this, function (_a) {
                            // logger.log("HttpClient.post", { url, formData })
                            Request({
                                url: url,
                                method: "POST",
                                rejectUnauthorized: false,
                                form: formData
                            }, function (error, response, body) {
                                if (error === null) {
                                    var result = body;
                                    if (response.statusCode !== 200) {
                                        return reject(new LarkError_1.LarkError("HttpClient#errorStatusCode", {
                                            url: url,
                                            formData: formData,
                                            statusCode: response.statusCode,
                                            body: body
                                        }));
                                    }
                                    if (format === "json") {
                                        try {
                                            result = JSON.parse(body);
                                        }
                                        catch (error) {
                                            return reject(new LarkError_1.LarkError("HttpClient#FormatError", { body: body }));
                                        }
                                    }
                                    resolve(result);
                                }
                                else {
                                    reject(new LarkError_1.LarkError("HttpClient", { url: url, formData: formData, error: error }));
                                }
                            });
                            return [2 /*return*/];
                        });
                    }); })];
            });
        });
    };
    /**
     * 获取网页的buffer数据，支持对Gzip解压的解析
     * @param url
     * @param options
     */
    HttpClient.get = function (url, options) {
        if (options === void 0) { options = { cache: false, gzip: true }; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                        var gzip, statusCode, content, count, option, req;
                        return tslib_1.__generator(this, function (_a) {
                            if (typeof options.gzip === "undefined") {
                                options.gzip = true;
                            }
                            if (typeof options.cache === "undefined") {
                                options.cache = true;
                            }
                            gzip = false;
                            statusCode = null;
                            content = [];
                            count = 0;
                            option = {
                                headers: {
                                    "Cookie": null,
                                    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) " +
                                        "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.101 Safari/537.36"
                                },
                                rejectUnauthorized: false,
                                uri: url
                            };
                            if (typeof options.cookies === "string") {
                                option.headers.Cookie = options.cookies;
                            }
                            if (options.gzip === true) {
                                option.headers["accept-encoding"] = "gzip";
                            }
                            req = Request(option);
                            // logger.log("HttpClient.get", JSON.stringify({ option }))
                            req.on("response", function (response) {
                                // logger.log("HttpClient.get.statusCode", response.statusCode)
                                statusCode = response.statusCode;
                                if (statusCode !== 200) {
                                    reject(new Error("NOT_FOUND"));
                                }
                                if (response.headers["content-encoding"]) {
                                    // logger.log("HttpClient.get.content-encoding", response.headers["content-encoding"])
                                }
                                if (response.headers["content-encoding"] === "gzip") {
                                    gzip = true;
                                }
                            });
                            req.on("data", function (chunk) {
                                if (statusCode !== 200) {
                                    return;
                                }
                                content.push(chunk);
                                count += chunk.length;
                            });
                            req.on("end", function () {
                                if (statusCode !== 200) {
                                    return;
                                }
                                var fileBuffer = Buffer.concat(content);
                                // logger.log("HttpClient.get.end")
                                if (gzip) {
                                    // logger.log("HttpClient.get.ungzip")
                                    try {
                                        fileBuffer = zlib.gunzipSync(fileBuffer);
                                    }
                                    catch (error) {
                                        reject(error);
                                        return;
                                    }
                                }
                                resolve(fileBuffer);
                            });
                            req.on("error", function (error) {
                                reject(error);
                            });
                            return [2 /*return*/];
                        });
                    }); })];
            });
        });
    };
    return HttpClient;
}());
exports.HttpClient = HttpClient;
//# sourceMappingURL=HttpClient.js.map