"use strict";
exports.__esModule = true;
var html_minifier_1 = require("html-minifier");
var markdown_1 = require("markdown");
var LarkError_1 = require("../Log/LarkError");
/**
 * 强大的字符串处理工具
 */
var LarkString = /** @class */ (function () {
    function LarkString() {
    }
    LarkString.pad = function (n, str) {
        str = str === undefined ? ' ' : str;
        if (typeof str !== 'string') {
            throw new TypeError("Expected `input` to be a `string`, got `" + typeof str + "`");
        }
        if (n < 0 || !Number.isFinite(n)) {
            throw new TypeError("Expected `count` to be a positive finite number, got `" + n + "`");
        }
        var ret = '';
        do {
            if (n & 1) {
                ret += str;
            }
            str += str;
        } while ((n >>= 1));
        return ret;
    };
    LarkString.trim = function (str) {
        return str.replace(/^\s*|\s*$/g, '');
    };
    LarkString.subString = function (str, start, end) {
        var startIndex = str.indexOf(start);
        if (startIndex === -1) {
            throw new LarkError_1.LarkError("LarkString.subString#未找到起始点", { start: start, end: end, startIndex: startIndex, str: str });
        }
        console.log(startIndex);
        var from = startIndex + start.length;
        var endIndex = str.indexOf(end);
        if (endIndex === -1) {
            throw new LarkError_1.LarkError("LarkString.subString#未找到结束点", { start: start, end: end, endIndex: endIndex, str: str });
        }
        var length = endIndex - from;
        return str.substr(from, length);
    };
    /**
     * 是否为全字母字符串，不含数字空格等一切非字母
     * @param str
     */
    LarkString.isAllEnglishCharacter = function (str) {
        return /^[a-zA-Z]+$/.test(str);
    };
    /**
     * 是否为全小写字母字符串
     * @param str 需要判断的字符串
     * @param length 是否判断长度
     */
    LarkString.isAllLowerCaseCharacter = function (str, length) {
        if (length === void 0) { length = null; }
        var result = null;
        if (length === null) {
            result = /^[a-z]+$/.test(str);
        }
        else {
            if (typeof length === "number") {
                length = { min: length, max: length };
            }
            console.log("^[a-z]{" + length.min + "," + length.max + "}$", str);
            result = new RegExp("^[a-z]{" + length.min + "," + length.max + "}$").test(str);
        }
        return result;
    };
    /**
     * 是否为sha1字符串
     * 特征 全字母+数字 40位长度
     */
    LarkString.isSHA1 = function (str) {
        return /^[0-9a-z]{40,40}$/.test(str);
    };
    /**
     * 是否为全大写字母字符串
     */
    /**
     * 是否为全中文
     */
    /**
     * 是否为全字母数字下划线字符串，非数字开头，不区分大小写
     */
    /**
     * 是否含有空格
     * @param str
     */
    LarkString.hasSpace = function (str) {
        return /\s/.test(str);
    };
    LarkString.isString = function (str) {
        return typeof str === "string";
    };
    /**
     * markdown转html功能
     * @param markdown md
     */
    LarkString.markdownToHTML = function (markdownText) {
        return markdown_1.markdown.toHTML(markdownText);
    };
    LarkString.HTMLToMarkdown = function () {
    };
    /**
     * 清除HTML片段里面的空格之类的
     */
    LarkString.cleanHTML = function (html, options) {
        if (options === void 0) { options = { collapseWhitespace: true }; }
        if (typeof html !== "string") {
            throw new LarkError_1.LarkError("不是String类型的数据", { html: html });
        }
        return html_minifier_1.minify(html, options);
    };
    LarkString.left = function (str) {
        return str.replace(/^\s*/, '');
    };
    LarkString.right = function (str) {
        return str.replace(/\s*$/, '');
    };
    return LarkString;
}());
exports.LarkString = LarkString;
//# sourceMappingURL=LarkString.js.map