"use strict";
exports.__esModule = true;
var TaskTime = /** @class */ (function () {
    function TaskTime() {
        this.total = null;
        this.index = 0;
        this.tookDatetime = null;
        this.lastTookDatetime = null;
        this.avgTime = null;
        this.diffTime = 0;
    }
    TaskTime.prototype.setTotal = function (total) {
        this.total = total;
    };
    TaskTime.prototype.getData = function () {
        return {
            rate: this.getRate() + "%",
            remainderAvgTime: (this.getRemainderAvgTime() / 1000).toFixed() + "s",
            remainderDiffTime: (this.getRemainderDiffTime() / 1000).toFixed() + "s"
        };
    };
    /**
     * 每节任务完成的进行快照
     * 首次运行时
     */
    TaskTime.prototype.take = function () {
        this.index++;
        this.lastTookDatetime = this.tookDatetime;
        this.tookDatetime = new Date();
        if (this.lastTookDatetime === null) {
            return;
        }
        var diffTime = this.tookDatetime.getTime() - this.lastTookDatetime.getTime();
        /**
         * 区分首次
         */
        if (diffTime > 0) {
            // 算法一
            // 平均时间等于相邻的一次任务所耗费的时间与前面所有任务耗费的时间除2
            this.avgTime = (this.avgTime + diffTime) / 2;
            // 算法二
            // 根据速度算时间
            this.diffTime = diffTime;
        }
    };
    /**
     * 获取剩余时间
     * @returns null 为null说明相关信息不够，无法计算剩余时间
     */
    TaskTime.prototype.getRemainderAvgTime = function () {
        if (this.avgTime === null) {
            return null;
        }
        var remainderTotal = this.total - this.index;
        // 剩余时间等于 平均时间乘以剩余的个数
        return this.avgTime * remainderTotal;
    };
    TaskTime.prototype.getRemainderDiffTime = function () {
        if (this.diffTime === null) {
            return null;
        }
        var remainderTotal = this.total - this.index;
        // 剩余时间等于 上一次时间乘以剩余的个数
        return this.diffTime * remainderTotal;
    };
    /**
     * 获取剩余比例
     */
    TaskTime.prototype.getRate = function () {
        if (this.total === null) {
            return 0;
        }
        // 计算比例，并格式化到百分制小数点2位
        return parseFloat(((this.index / this.total) * 100).toFixed(2));
    };
    return TaskTime;
}());
exports.TaskTime = TaskTime;
//# sourceMappingURL=TaskTime.js.map