/// <reference types="express" />
/// <reference types="node" />
import * as Express from "express";
import { E_STATUS_CODE } from "./Controller/ControllerDto";
import { LarkLogger } from '../index';
export declare class Controller {
    static defaultMaxExecutionTime: number;
    static setDefaultTimeLimit(defaultMaxExecutionTime: any): void;
    request: Express.Request;
    response: Express.Response;
    next: Express.NextFunction;
    origin: any;
    protected logger: LarkLogger | Console;
    private maxExecutionTime;
    constructor(request?: any, response?: any, next?: any);
    setContentType(extname: any): void;
    getParam(name: string, defaultValue?: any): any;
    /**
     * 获取get参数
     */
    getQuery(query: string, defaultValue?: string): any;
    /**
     * 获取post参数
     */
    getPost(query: string, defaultValue?: string): any;
    /**
     * 获取cookie
     */
    getCookie(cookieName: string, defaultValue?: string): any;
    /**
     * 获取整个cookies
     */
    getCookies(): any;
    /**
     * 设置cookie
     */
    setCookie(name: string, val: string, options?: Express.CookieOptions): void;
    /**
     * 清除cookie
     * @param name
     * @param options
     */
    clearCookie(name: string, options?: any): void;
    /**
     * 重定向访问
     */
    redirect(url: string): void;
    /**
     * @deprecated 过时了方法，请使用setCORS
     */
    setOrigin(): void;
    /**
     * 配置某个接口的跨域规则，一次请求只能使用一次！
     * @param originRegex 跨域规则
     */
    setCORS(originRegex?: RegExp): this;
    /**
     * 发送buffer
     */
    sendBuffer(buf: Buffer): void;
    /**
     *
     * @param buf
     */
    sendDownload(buf: Buffer): void;
    /**
     *
     * @param json
     */
    sendJSONP(json: any, statusCode?: E_STATUS_CODE): void;
    /**
     *
     * @param mime
     */
    setMIME(mime: any): void;
    /**
     * ok
     * @param responseJSON
     */
    ok(responseJSON: object | any): void;
    /**
     *
     * @param content
     * @param statusCode
     */
    sendJSON(content: any, statusCode?: E_STATUS_CODE): void;
    /**
     *
     * @param html
     */
    sendHTML(html: string): void;
    /**
     * @deprecated 过时的方法，请使用sendJSON
     * @param content
     */
    json(content: any): void;
    /**
     * 发送
     * @param content
     */
    send(content: any): void;
    isSend(): boolean;
    isXHR(): boolean;
    /**
     * 配置超时时间
     * @param maxExecutionTime 超时时间，为0永不超时
     */
    setTimeLimit(maxExecutionTime: any): void;
    getTimeLimit(): number;
    private init(request, response, next);
}
