"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var Controller_1 = require("../Controller");
var PageController = /** @class */ (function (_super) {
    tslib_1.__extends(PageController, _super);
    function PageController() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        // 网页使用的标题
        _this.title = null;
        // body下文的脚本
        _this.script = [];
        // 整站样式的位置
        _this.style = [];
        // head当中插入的脚本
        _this.headScript = [];
        _this.meta = [];
        _this.link = [];
        // protected logger = new Logger("Web/PageController")
        // 主要给HTML用的属性
        _this.props = {};
        // 主要给Page用的属性
        _this.data = {};
        return _this;
    }
    PageController.getCDN = function () {
        return this.cdn;
    };
    PageController.setCDNServer = function (server) {
        console.log("PageController.setCDNServer", server);
        this.cdnServer = server;
    };
    PageController.getCDNServer = function () {
        return this.cdnServer;
    };
    PageController.getStaticURL = function () {
        return this.getCDNServer() + this.getCDN();
    };
    /**
     * @deprecated 内部的方法，请不要手动调用
     * @param cdn
     */
    PageController.setCDN = function (cdn) {
        cdn = cdn.replace(/^\//, "");
        cdn = cdn.replace(/\/$/, "");
        if (cdn === "") {
            cdn = "/";
        }
        else {
            cdn = "/" + cdn + "/";
        }
        this.cdn = cdn;
    };
    PageController.prototype.initPageController = function () {
        if (process.env.NODE_ENV) {
            this.meta.push({
                content: process.env.NODE_ENV ? process.env.NODE_ENV : "dev",
                name: "envName"
            });
        }
        this.setViewPort();
        this.addLink({
            rel: "shortcut icon",
            href: PageController.getCDN() + "logo.png"
        });
    };
    /**
     * 设置网页标题
     * @param title 网页标题
     */
    PageController.prototype.setTitle = function (title) {
        this.title = title;
    };
    /**
     * 添加meta
     * @param meta
     */
    PageController.prototype.addMeta = function (meta) {
        this.meta.push(meta);
    };
    /**
     * 添加link
     * @param link
     */
    PageController.prototype.addLink = function (link) {
        this.link.push(link);
    };
    /**
     * 设置setViewPort
     * @param content 可不填写，默认为"width=device-width, initial-scale=1, maximum-scale=1"
     */
    PageController.prototype.setViewPort = function (content) {
        if (content === void 0) { content = "width=device-width, initial-scale=1, maximum-scale=1"; }
        this.meta.push({
            content: content,
            name: "viewport"
        });
    };
    /**
     * 设置控制器使用的用于渲染Page组件的属性
     * @param {object} data 用于渲染Page组件的属性
     * @return {Controller} 返回实例化后的控制器对象
     */
    PageController.prototype.setData = function (data) {
        this.data = data;
        return this;
    };
    /**
     * 配置当前控制器使用的脚本
     * @param {string[]} script 配置当前控制器使用的脚本
     */
    PageController.prototype.setScript = function (script) {
        this.script = script;
    };
    /**
     * 获得当前设置的控制器数据
     * @return {object} 控制器的数据 default {}
     */
    PageController.prototype.getData = function () {
        return this.data;
    };
    /**
     * 设置页面的属性
     */
    PageController.prototype.setProps = function (props) {
        this.props = props;
        return this;
    };
    /**
     * 获得页面的属性
     */
    PageController.prototype.getProps = function () {
        return this.props;
    };
    /**
     * 给页面添加脚本
     * 如果第二个参数为true，则意味着不使用cdn，直接使用第一个参数作为地址
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    PageController.prototype.addScript = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController.getStaticURL() + "Script/" + href + ".js";
        }
        this.script.push(href);
        return this;
    };
    /**
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    PageController.prototype.addHeadScript = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController.getStaticURL() + "Script/" + href + ".js";
        }
        this.headScript.push(href);
        return this;
    };
    /**
     * 给页面添加样式
     */
    PageController.prototype.addStyle = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController.getStaticURL() + "Style/" + href + ".css";
        }
        this.style.push(href);
        return this;
    };
    /**
     * 渲染页面
     */
    PageController.prototype.render = function (view, data, option) {
        var _this = this;
        if (view === void 0) { view = ""; }
        if (data === void 0) { data = {}; }
        if (option === void 0) { option = {}; }
        this.initPageController();
        if (data !== null) {
            this.setData(data);
        }
        var page = {
            cdn: PageController.getCDN(),
            cdnServer: PageController.getCDNServer(),
            headScript: this.headScript,
            linkDoms: this.getLinkDom().join(""),
            metaDoms: this.getMetaDom().join(""),
            scriptDoms: this.getScriptDom().join(""),
            staticURL: PageController.getStaticURL(),
            style: this.style,
            title: this.title
        };
        // ejs的render
        var viewData = Object.assign(data, {
            page: page
        });
        this.response.render(view, Object.assign(data, this.props), function (error, html) {
            if (error === null) {
                // 已由编译工具完成压缩工作，无需程序处理
                // html = html.replace(/\r|\n|\r\n/g, "");
                _this.sendHTML(html);
            }
            else {
                _this.next(error);
            }
        });
    };
    PageController.prototype.getScriptDom = function () {
        var scriptDom = [];
        for (var i = 0; i < this.script.length; i++) {
            var source = this.script[i];
            scriptDom.push("<script src=\"" + source + "\"></script>");
        }
        return scriptDom;
    };
    PageController.prototype.getLinkDom = function () {
        var linkDOM = [];
        for (var i = 0; i < this.style.length; i++) {
            var source = this.style[i];
            linkDOM.push("<link href=\"" + source + "\" rel=\"stylesheet\" />");
        }
        // 定义了link
        if (this.link) {
            this.link.map(function (item, index) {
                var link = [];
                for (var key in item) {
                    if (item.hasOwnProperty(key)) {
                        link.push(key + "=\"" + item[key] + "\"");
                    }
                }
                linkDOM.push("<link " + link.join(" ") + " />");
            });
        }
        return linkDOM;
    };
    PageController.prototype.getMetaDom = function () {
        var metaDom = ["<meta charset=\"utf-8\" />"];
        // let meta = [];
        // 如果有自定义meta，则连接它们
        // if (this.props.envName) {
        //     meta.push({ content: this.props.envName, name: "envName" });
        // }
        if (PageController.startupDate) {
            this.meta.push({ content: PageController.startupDate.toString(), name: "startupDate" });
        }
        // if (this.props.cdn) {
        //     meta.push({ content: this.props.cdn, name: "cdn" });
        // }
        // if (this.props.cdnServer) {
        //     meta.push({ content: this.props.cdnServer, name: "cdnServer" });
        // }
        // if (this.props.staticURL) {
        //     meta.push({ content: this.props.staticURL, name: "staticURL" });
        // }
        // if (this.meta instanceof Array) {
        //     meta = meta.concat(this.props.meta);
        // }
        this.meta.map(function (item, index) {
            metaDom.push("<meta name=\"" + item.name + "\" content=\"" + item.content + "\" />");
        });
        return metaDom;
    };
    PageController.cdn = "/";
    PageController.cdnServer = "";
    PageController.envName = null;
    PageController.startupDate = null;
    return PageController;
}(Controller_1.Controller));
exports.PageController = PageController;
//# sourceMappingURL=PageController.js.map