"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var React = require("react");
var HTML = /** @class */ (function (_super) {
    tslib_1.__extends(HTML, _super);
    function HTML() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     *
     * 页面渲染
     * @returns
     * @memberOf Page
     */
    HTML.prototype.render = function () {
        return (React.createElement("html", null,
            React.createElement("head", null,
                this.renderTitle(),
                this.renderMeta(),
                this.renderLink(),
                this.renderHeadScript()),
            React.createElement("body", null,
                this.props.children,
                this.renderScript())));
    };
    /**
     * 处理meta
     */
    HTML.prototype.renderMeta = function () {
        var metaDom = [React.createElement("meta", { key: "meta-charset", charSet: "utf-8" })];
        var meta = [];
        // 如果有自定义meta，则连接它们
        if (this.props.envName) {
            meta.push({ content: this.props.envName, name: "envName" });
        }
        if (this.props.startupDate) {
            meta.push({ content: this.props.startupDate.toString(), name: "startupDate" });
        }
        if (this.props.cdn) {
            meta.push({ content: this.props.cdn, name: "cdn" });
        }
        if (this.props.cdnServer) {
            meta.push({ content: this.props.cdnServer, name: "cdnServer" });
        }
        if (this.props.staticURL) {
            meta.push({ content: this.props.staticURL, name: "staticURL" });
        }
        if (this.props.meta instanceof Array) {
            meta = meta.concat(this.props.meta);
        }
        meta.map(function (item, index) {
            metaDom.push(React.createElement("meta", { name: item.name, content: item.content, key: "meta-" + item.name + index }));
        });
        return metaDom;
    };
    HTML.prototype.renderTitle = function () {
        var titleDom = null;
        if (this.props.title) {
            titleDom = React.createElement("title", null, this.props.title);
        }
        return titleDom;
    };
    HTML.prototype.renderHeadScript = function () {
        var script = [];
        for (var i = 0; i < this.props.headScript.length; i++) {
            var source = this.props.headScript[i];
            script.push(React.createElement("script", { key: "script-" + i, src: source }));
        }
        return script;
    };
    /**
     * 外链样式渲染
     * @returns
     * @memberOf Page
     */
    HTML.prototype.renderLink = function () {
        var linkDOM = [];
        for (var i = 0; i < this.props.style.length; i++) {
            var source = this.props.style[i];
            linkDOM.push(React.createElement("link", { key: "style-" + i, href: source, rel: "stylesheet" }));
        }
        // 定义了link
        if (this.props.link) {
            this.props.link.map(function (item, index) {
                item.key = "link-" + index;
                linkDOM.push(React.createElement("link", item));
            });
        }
        return linkDOM;
    };
    /**
     * 外链脚本渲染
     * @returns
     * @memberOf Page
     */
    HTML.prototype.renderScript = function () {
        var script = [];
        for (var i = 0; i < this.props.script.length; i++) {
            var source = this.props.script[i];
            script.push(React.createElement("script", { key: "script-" + i, src: source }));
        }
        return script;
    };
    return HTML;
}(React.Component));
exports.HTML = HTML;
//# sourceMappingURL=HTML.js.map