"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var React = require("react");
var ReactDOMServer = require("react-dom/server");
var Controller_1 = require("../../Controller");
var HTML_1 = require("./HTML");
var Page_1 = require("./Page");
var PageController_1 = require("../PageController");
var ReactPageController = /** @class */ (function (_super) {
    tslib_1.__extends(ReactPageController, _super);
    function ReactPageController(request, response, next) {
        var _this = _super.call(this, request, response, next) || this;
        // 网页使用的标题
        _this.title = null;
        // body下文的脚本
        _this.script = [];
        // 整站样式的位置
        _this.style = [];
        // head当中插入的脚本
        _this.headScript = [];
        _this.meta = [];
        _this.link = [];
        _this.page = Page_1.Page;
        // 主要给HTML用的属性
        _this.props = {};
        // 主要给Page用的属性
        _this.data = {};
        if (process.env.NODE_ENV) {
            _this.meta.push({
                content: process.env.NODE_ENV ? process.env.NODE_ENV : "dev",
                name: "envName"
            });
            _this.setViewPort();
        }
        return _this;
    }
    /**
     * 设置网页标题
     * @param title 网页标题
     */
    ReactPageController.prototype.setTitle = function (title) {
        this.title = title;
    };
    /**
     * 添加meta
     * @param meta
     */
    ReactPageController.prototype.addMeta = function (meta) {
        this.meta.push(meta);
    };
    /**
     * 添加link
     * @param link
     */
    ReactPageController.prototype.addLink = function (link) {
        this.link.push(link);
    };
    /**
     * 设置setViewPort
     * @param content 可不填写，默认为"width=device-width, initial-scale=1, maximum-scale=1"
     */
    ReactPageController.prototype.setViewPort = function (content) {
        if (content === void 0) { content = "width=device-width, initial-scale=1, maximum-scale=1"; }
        this.meta.push({
            content: content,
            name: "viewport"
        });
    };
    /**
     * 设置控制器使用的用于渲染Page组件的属性
     * @param {object} data 用于渲染Page组件的属性
     * @return {Controller} 返回实例化后的控制器对象
     */
    ReactPageController.prototype.setData = function (data) {
        this.data = data;
        return this;
    };
    /**
     * 配置当前控制器使用的脚本
     * @param {string[]} script 配置当前控制器使用的脚本
     */
    ReactPageController.prototype.setScript = function (script) {
        this.script = script;
    };
    /**
     * 获得当前设置的控制器数据
     * @return {object} 控制器的数据 default {}
     */
    ReactPageController.prototype.getData = function () {
        return this.data;
    };
    /**
     * 设置控制器使用的页面
     * @param {Component} page React Page组件
     * @return {Controller} 返回实例化后的控制器对象
     */
    ReactPageController.prototype.setPage = function (page) {
        this.page = page;
        return this;
    };
    /**
     * 获得控制器使用的页面
     * @return {Component} React Page组件
     */
    ReactPageController.prototype.getPage = function () {
        return this.page;
    };
    /**
     * 设置页面的属性
     */
    ReactPageController.prototype.setProps = function (props) {
        this.props = props;
        return this;
    };
    /**
     * 获得页面的属性
     */
    ReactPageController.prototype.getProps = function () {
        return this.props;
    };
    /**
     * 给页面添加脚本
     * 如果第二个参数为true，则意味着不使用cdn，直接使用第一个参数作为地址
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    ReactPageController.prototype.addScript = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController_1.PageController.getStaticURL() + "Script/" + href + ".js";
        }
        this.script.push(href);
        return this;
    };
    /**
     * @param script 需要加载的脚本的URI
     * @param local 是否为站内脚本
     */
    ReactPageController.prototype.addHeadScript = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController_1.PageController.getStaticURL() + "Script/" + href + ".js";
        }
        this.headScript.push(href);
        return this;
    };
    /**
     * 给页面添加样式
     */
    ReactPageController.prototype.addStyle = function (href, remote) {
        if (remote === void 0) { remote = false; }
        if (remote === false) {
            href = PageController_1.PageController.getStaticURL() + "Style/" + href + ".css";
        }
        this.style.push(href);
        return this;
    };
    /**
     * 渲染页面
     */
    ReactPageController.prototype.render = function (view, data) {
        if (view === void 0) { view = null; }
        if (data === void 0) { data = {}; }
        if (data !== null) {
            this.setData(data);
        }
        var props = {
            headScript: this.headScript,
            link: this.link,
            meta: this.meta,
            script: this.script,
            style: this.style,
            title: this.title
        };
        this.setProps(props);
        // 新的render
        if (view !== null) {
            this.setPage(view);
        }
        var page = React.createElement(this.page, this.data);
        var html = React.createElement(HTML_1.HTML, this.props, page);
        var content = "<!doctype html>" + ReactDOMServer.renderToStaticMarkup(html);
        this.sendHTML(content);
    };
    return ReactPageController;
}(Controller_1.Controller));
exports.ReactPageController = ReactPageController;
//# sourceMappingURL=ReactPageController.js.map