"use strict";
exports.__esModule = true;
var tslib_1 = require("tslib");
var BodyParser = require("body-parser");
var Compression = require("compression");
var CookieParser = require("cookie-parser");
var Express = require("express");
var fs = require("fs-extra");
var Http = require("http");
var Path = require("path");
var Http2 = require("spdy");
var PageController_1 = require("./Controller/PageController");
var WebServerDto_1 = require("./WebServerDto");
// import * as WEB_SERVER_CONFIG from "../../Config/WebServer"
var WebServer = /** @class */ (function () {
    function WebServer() {
        this.app = null;
        this.router = null;
        this.staticRootPath = null;
        this.CONFIG = WebServerDto_1.WEB_SERVER_CONFIG;
    }
    /**
     * 进行应用配置
     * @param config
     */
    WebServer.prototype.initCONFIG = function () {
        try {
            var config = fs.readJSONSync("config/web.json");
            this.CONFIG = Object.assign(this.CONFIG, config);
            // console.log(this.CONFIG)
        }
        catch (error) {
            // 
        }
    };
    /**
     * 挂载该Web服务器的router点
     * @param router
     */
    WebServer.prototype.setRouter = function (router) {
        this.router = router;
        return this;
    };
    /**
     * 配置其它自定义中间件
     */
    WebServer.prototype.useMiddleware = function (handler) {
        this.app.use(handler);
        return this;
    };
    /**
     * 关闭该web服务器
     */
    WebServer.prototype.close = function () {
        if (this.CONFIG.PORT !== null) {
            this.httpServer.close();
        }
        if (this.CONFIG.SSL_PORT !== null) {
            this.httpsServer.close();
        }
    };
    WebServer.prototype.bootstrap = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.app = Express();
                        this.initCONFIG();
                        this.setCDN();
                        this.app.set("view engine", "ejs");
                        this.app.set("views", Path.resolve("View"));
                        this.setStaticServerRootPath(Path.resolve("Browser"));
                        this.setCloseHandle();
                        return [4 /*yield*/, this.ready()];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.startup()];
                    case 2:
                        _a.sent();
                        console.info("================================");
                        console.info("");
                        return [2 /*return*/, this];
                }
            });
        });
    };
    /**
     * 配置项目根路径
     * @param {string} staticRootPath 一般为__dirname
     */
    WebServer.prototype.setStaticServerRootPath = function (staticRootPath) {
        // console.log("setStaticServerRootPath", "staticRootPath", staticRootPath)
        this.staticRootPath = staticRootPath;
        return this;
    };
    /**
     * 处理退出时的事件
     */
    WebServer.prototype.setCloseHandle = function () {
        var _this = this;
        process.once("SIGINT", function () {
            _this.close();
        });
    };
    WebServer.prototype.ready = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.errorEventHandler();
                this.setMiddleware();
                return [2 /*return*/, this];
            });
        });
    };
    /**
     * 异常事件注册
     */
    WebServer.prototype.errorEventHandler = function () {
        process.on("uncaughtException", function (error) {
            console.error("errorEventHandler", "UNCAUGHT_EXCEPTION", "!!!未处理的严重异常.被process.uncaughtException捕获!!!", error);
        });
    };
    WebServer.prototype.startup = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.listenHTTP()];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.listenHTTPS()];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    WebServer.prototype.listenHTTP = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                if (this.CONFIG.PORT === null) {
                    return [2 /*return*/];
                }
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        _this.httpServer = Http.createServer(_this.app);
                        _this.httpServer.listen(_this.CONFIG.PORT, function (error) {
                            if (error) {
                                reject(error);
                            }
                            else {
                                console.log("listen http", _this.CONFIG.PORT);
                                resolve();
                            }
                        });
                    })];
            });
        });
    };
    WebServer.prototype.listenHTTPS = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                if (this.CONFIG.SSL_PORT === null) {
                    return [2 /*return*/];
                }
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        _this.httpsServer = Http2.createServer({
                            cert: _this.CONFIG.CERT,
                            key: _this.CONFIG.KEY
                        }, _this.app);
                        _this.httpsServer.listen(_this.CONFIG.SSL_PORT, function (error) {
                            if (error) {
                                reject(error);
                            }
                            else {
                                console.log("listen https", _this.CONFIG.SSL_PORT);
                                resolve();
                            }
                        });
                    })];
            });
        });
    };
    /**
     * 从package.json当中读取cdn，并进行配置
     */
    WebServer.prototype.setCDN = function () {
        try {
            var packageJSON = fs.readJSONSync("./package.json");
            PageController_1.PageController.setCDN(packageJSON.cdn ? packageJSON.cdn : "");
        }
        catch (error) {
            throw new Error("CAN_NOT_READ_PACKAGE_JSON");
        }
    };
    /**
     * 中间件配置
     * 注意：执行顺序对应用的影响
     */
    WebServer.prototype.setMiddleware = function () {
        this.app.use(Compression());
        this.app.use(CookieParser());
        this.app.use(BodyParser.json());
        this.app.use(BodyParser.urlencoded({
            limit: 10 * 1024 * 1024,
            extended: true
        }));
        if (this.staticRootPath !== null) {
            this.app.use(Express.static(Path.resolve(this.staticRootPath), {
                setHeaders: function (res, path, stat) {
                    var ext = Path.parse(path).ext;
                    switch (ext) {
                        case ".css":
                            res.setHeader("content-type", "text/css; charset=utf-8");
                            break;
                        case ".js":
                            res.setHeader("content-type", "application/javascript; charset=utf-8");
                            break;
                    }
                }
            }));
        }
        if (this.router !== null) {
            this.app.use(this.router.getRouter());
        }
    };
    return WebServer;
}());
exports.WebServer = WebServer;
//# sourceMappingURL=WebServer.js.map